# RapidPE

The original low-latency gravitational wave parameter estimation code.


# Credit

Copyright (c) 2012-2022 RapidPE Contributors

Past and present RapidPE Contributors ordered by given name:

- Caitlin Rose
- Chris Pankow
- Daniel Wysocki
- Evan Oschner
- Hong Qi
- Patrick Brady
- Richard O'Shaughnessy
- Sinead Walsh
- Soichiro Morisaki
- Vinaya Valsan
